So init_thread_xstate() is a misnomer in that it's not really related to a 
specific
thread - it determines, once during initial bootup, the size of the xstate 
context.

Also improve the comments.

Reviewed-by: Borislav Petkov <b...@alien8.de>
Cc: Andy Lutomirski <l...@amacapital.net>
Cc: Dave Hansen <dave.han...@linux.intel.com>
Cc: Fenghua Yu <fenghua...@intel.com>
Cc: H. Peter Anvin <h...@zytor.com>
Cc: Linus Torvalds <torva...@linux-foundation.org>
Cc: Oleg Nesterov <o...@redhat.com>
Cc: Thomas Gleixner <t...@linutronix.de>
Signed-off-by: Ingo Molnar <mi...@kernel.org>
---
 arch/x86/kernel/i387.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/arch/x86/kernel/i387.c b/arch/x86/kernel/i387.c
index 5b4672584e65..01101553c6c1 100644
--- a/arch/x86/kernel/i387.c
+++ b/arch/x86/kernel/i387.c
@@ -158,7 +158,7 @@ static void mxcsr_feature_mask_init(void)
        mxcsr_feature_mask &= mask;
 }
 
-static void init_thread_xstate(void)
+static void fpstate_xstate_init_size(void)
 {
        /*
         * Note that xstate_size might be overwriten later during
@@ -216,11 +216,11 @@ void fpu__cpu_init(void)
        write_cr0(cr0);
 
        /*
         * init_thread_xstate is only called once to avoid overriding
         * xstate_size during boot time or during CPU hotplug.
         */
        if (xstate_size == 0)
-               init_thread_xstate();
+               fpstate_xstate_init_size();
 
        mxcsr_feature_mask_init();
        xsave_init();
@@ -216,11 +216,11 @@ void fpu__cpu_init(void)
 
        /*
-        * init_thread_xstate is only called once to avoid overriding
-        * xstate_size during boot time or during CPU hotplug.
+        * fpstate_xstate_init_size() is only called once, to avoid overriding
+        * 'xstate_size' during (secondary CPU) bootup or during CPU hotplug.
         */
        if (xstate_size == 0)
-- 
2.1.0

--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Reply via email to